==> die-engine_3.03.orig.tar.gz: die-engine-3.03/XTranslation/README.md <==
[![gitlocalized ](https://gitlocalize.com/repo/4736/whole_project/badge.svg)](https://gitlocalize.com/repo/4736/whole_project?utm_source=badge)

Translation for:

* Detect It Easy: https://github.com/horsicq/Detect-It-Easy
* XAPKDetector: https://github.com/horsicq/XAPKDetector
* XELFViewer: https://github.com/horsicq/XELFViewer
* XPEViewer: https://github.com/horsicq/XPEViewer
* XMACHOViewer: https://github.com/horsicq/XMACHOViewer
* PDBRipper: https://github.com/horsicq/PDBRipper
* XNTSV: https://github.com/horsicq/xntsv

| Language | % |
| --- | --- |
| Arabic               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ar.po"> <img src="https://gitlocalize.com/repo/4736/ar/badge.svg" /> </a> |
| German               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_de.po"> <img src="https://gitlocalize.com/repo/4736/de/badge.svg" /> </a> |
| Spanish              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_es.po"> <img src="https://gitlocalize.com/repo/4736/es/badge.svg" /> </a> |
| French               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_fr.po"> <img src="https://gitlocalize.com/repo/4736/fr/badge.svg" /> </a> |
| Hebrew               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_he.po"> <img src="https://gitlocalize.com/repo/4736/he/badge.svg" /> </a> |
| Indonesian           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_id.po"> <img src="https://gitlocalize.com/repo/4736/id/badge.svg" /> </a> |
| Italian              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_it.po"> <img src="https://gitlocalize.com/repo/4736/it/badge.svg" /> </a> |
| Japanese             | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ja.po"> <img src="https://gitlocalize.com/repo/4736/ja/badge.svg" /> </a> |
| Korean               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ko.po"> <img src="https://gitlocalize.com/repo/4736/ko/badge.svg" /> </a> |
| Polish               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pl.po"> <img src="https://gitlocalize.com/repo/4736/pl/badge.svg" /> </a> |
| Portuguese           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pt-PT.po"> <img src="https://gitlocalize.com/repo/4736/pt/badge.svg" /> </a> |
| Portuguese, Brazil   | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pt-BR.po"> <img src="https://gitlocalize.com/repo/4736/pt_BR/badge.svg" /> </a> |
| Russian              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ru.po"> <img src="https://gitlocalize.com/repo/4736/ru/badge.svg" /> </a> |
| Turkish              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_tr.po"> <img src="https://gitlocalize.com/repo/4736/tr/badge.svg" /> </a> |
| Vietnamese           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_vi.po"> <img src="https://gitlocalize.com/repo/4736/vi/badge.svg" /> </a> |
| Chinese              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_zh.po"> <img src="https://gitlocalize.com/repo/4736/zh/badge.svg" /> </a> |
| Chinese, Taiwan      | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_zh-TW.po"> <img src="https://gitlocalize.com/repo/4736/zh-TW/badge.svg" /> </a> |

Thank you to all the people who already contributed!

==> die-engine_3.07.orig.tar.gz: die-engine-3.07/XTranslation/README.md <==
[![gitlocalized ](https://gitlocalize.com/repo/4736/whole_project/badge.svg)](https://gitlocalize.com/repo/4736/whole_project?utm_source=badge)

Translation for:

* Detect It Easy: https://github.com/horsicq/Detect-It-Easy
* Nauz File Detector: https://github.com/horsicq/Nauz-File-Detector
* XAPKDetector: https://github.com/horsicq/XAPKDetector
* XELFViewer: https://github.com/horsicq/XELFViewer
* XPEViewer: https://github.com/horsicq/XPEViewer
* XMACHOViewer: https://github.com/horsicq/XMACHOViewer
* PDBRipper: https://github.com/horsicq/PDBRipper
* XNTSV: https://github.com/horsicq/xntsv

| Language | % |
| --- | --- |
| Arabic               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ar.po"> <img src="https://gitlocalize.com/repo/4736/ar/badge.svg" /> </a> |
| Chinese              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_zh.po"> <img src="https://gitlocalize.com/repo/4736/zh/badge.svg" /> </a> |
| Chinese, Taiwan      | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_zh-TW.po"> <img src="https://gitlocalize.com/repo/4736/zh-TW/badge.svg" /> </a> |
| French               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_fr.po"> <img src="https://gitlocalize.com/repo/4736/fr/badge.svg" /> </a> |
| German               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_de.po"> <img src="https://gitlocalize.com/repo/4736/de/badge.svg" /> </a> |
| Hebrew               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_he.po"> <img src="https://gitlocalize.com/repo/4736/he/badge.svg" /> </a> |
| Indonesian           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_id.po"> <img src="https://gitlocalize.com/repo/4736/id/badge.svg" /> </a> |
| Italian              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_it.po"> <img src="https://gitlocalize.com/repo/4736/it/badge.svg" /> </a> |
| Japanese             | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ja.po"> <img src="https://gitlocalize.com/repo/4736/ja/badge.svg" /> </a> |
| Korean               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ko.po"> <img src="https://gitlocalize.com/repo/4736/ko/badge.svg" /> </a> |
| Polish               | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pl.po"> <img src="https://gitlocalize.com/repo/4736/pl/badge.svg" /> </a> |
| Portuguese           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pt-PT.po"> <img src="https://gitlocalize.com/repo/4736/pt/badge.svg" /> </a> |
| Portuguese, Brazil   | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_pt-BR.po"> <img src="https://gitlocalize.com/repo/4736/pt_BR/badge.svg" /> </a> |
| Russian              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_ru.po"> <img src="https://gitlocalize.com/repo/4736/ru/badge.svg" /> </a> |
| Spanish              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_es.po"> <img src="https://gitlocalize.com/repo/4736/es/badge.svg" /> </a> |
| Turkish              | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_tr.po"> <img src="https://gitlocalize.com/repo/4736/tr/badge.svg" /> </a> |
| Ukrainian           	| <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_uk.po"> <img src="https://gitlocalize.com/repo/4736/uk/badge.svg" /> </a> |
| Vietnamese           | <a href="https://github.com/horsicq/XTranslation/blob/master/dicts/dict_vi.po"> <img src="https://gitlocalize.com/repo/4736/vi/badge.svg" /> </a> |

Thanks to all the people who already contributed!

<a href="https://github.com/horsicq/XTranslation/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=horsicq/XTranslation" />
</a>
